@@ -1,12 +1,12 @@
 package XML::RSS;
-
 use strict;
 use Carp;
 use XML::Parser;
-use vars qw($VERSION $AUTOLOAD @ISA $modules $AUTO_ADD);
+use HTML::Entities qw(encode_entities);
+use vars qw($VERSION $AUTOLOAD $modules $AUTO_ADD);
+use base qw(XML::Parser);
 
-$VERSION = '1.10';
-@ISA = qw(XML::Parser);
+$VERSION = '1.11';
 
 $AUTO_ADD = 0;
 
@@ -1230,7 +1230,7 @@ sub as_rss_2_0 {
             $output .= '<pubDate>'.$self->encode($item->{pubDate}).'</pubDate>'."\n"
                 if $item->{pubDate};
 
-            $output .= '<source url="'.$self->encode($item->{sourceUrl}).'">'.$item->{source}.'</source>'."\n"
+            $output .= '<source url="'.$self->encode($item->{sourceUrl}).'">'.$self->encode($item->{source}).'</source>'."\n"
                 if $item->{source} && $item->{sourceUrl};
 
             if (my $e = $item->{enclosure})
@@ -1610,7 +1610,8 @@ sub parsefile {
 
 sub save {
     my ($self,$file) = @_;
-    open(OUT,">$file") || croak "Cannot open file $file for write: $!";
+    open(OUT, ">:encoding($self->{encoding})", "$file") 
+      or croak "Cannot open file $file for write: $!";
     print OUT $self->as_string;
     close OUT;
 }
@@ -1675,134 +1676,21 @@ sub AUTOLOAD {
 	#}
 }
 
-# the code here is a minorly tweaked version of code from
-# Matts' rssmirror.pl script
-#
-my %entity = (
-	      nbsp   => "&#160;",
-	      iexcl  => "&#161;",
-	      cent   => "&#162;",
-	      pound  => "&#163;",
-	      curren => "&#164;",
-	      yen    => "&#165;",
-	      brvbar => "&#166;",
-	      sect   => "&#167;",
-	      uml    => "&#168;",
-	      copy   => "&#169;",
-	      ordf   => "&#170;",
-	      laquo  => "&#171;",
-	      not    => "&#172;",
-	      shy    => "&#173;",
-	      reg    => "&#174;",
-	      macr   => "&#175;",
-	      deg    => "&#176;",
-	      plusmn => "&#177;",
-	      sup2   => "&#178;",
-	      sup3   => "&#179;",
-	      acute  => "&#180;",
-	      micro  => "&#181;",
-	      para   => "&#182;",
-	      middot => "&#183;",
-	      cedil  => "&#184;",
-	      sup1   => "&#185;",
-	      ordm   => "&#186;",
-	      raquo  => "&#187;",
-	      frac14 => "&#188;",
-	      frac12 => "&#189;",
-	      frac34 => "&#190;",
-	      iquest => "&#191;",
-	      Agrave => "&#192;",
-	      Aacute => "&#193;",
-	      Acirc  => "&#194;",
-	      Atilde => "&#195;",
-	      Auml   => "&#196;",
-	      Aring  => "&#197;",
-	      AElig  => "&#198;",
-	      Ccedil => "&#199;",
-	      Egrave => "&#200;",
-	      Eacute => "&#201;",
-	      Ecirc  => "&#202;",
-	      Euml   => "&#203;",
-	      Igrave => "&#204;",
-	      Iacute => "&#205;",
-	      Icirc  => "&#206;",
-	      Iuml   => "&#207;",
-	      ETH    => "&#208;",
-	      Ntilde => "&#209;",
-	      Ograve => "&#210;",
-	      Oacute => "&#211;",
-	      Ocirc  => "&#212;",
-	      Otilde => "&#213;",
-	      Ouml   => "&#214;",
-	      times  => "&#215;",
-	      Oslash => "&#216;",
-	      Ugrave => "&#217;",
-	      Uacute => "&#218;",
-	      Ucirc  => "&#219;",
-	      Uuml   => "&#220;",
-	      Yacute => "&#221;",
-	      THORN  => "&#222;",
-	      szlig  => "&#223;",
-	      agrave => "&#224;",
-	      aacute => "&#225;",
-	      acirc  => "&#226;",
-	      atilde => "&#227;",
-	      auml   => "&#228;",
-	      aring  => "&#229;",
-	      aelig  => "&#230;",
-	      ccedil => "&#231;",
-	      egrave => "&#232;",
-	      eacute => "&#233;",
-	      ecirc  => "&#234;",
-	      euml   => "&#235;",
-	      igrave => "&#236;",
-	      iacute => "&#237;",
-	      icirc  => "&#238;",
-	      iuml   => "&#239;",
-	      eth    => "&#240;",
-	      ntilde => "&#241;",
-	      ograve => "&#242;",
-	      oacute => "&#243;",
-	      ocirc  => "&#244;",
-	      otilde => "&#245;",
-	      ouml   => "&#246;",
-	      divide => "&#247;",
-	      oslash => "&#248;",
-	      ugrave => "&#249;",
-	      uacute => "&#250;",
-	      ucirc  => "&#251;",
-	      uuml   => "&#252;",
-	      yacute => "&#253;",
-	      thorn  => "&#254;",
-	      yuml   => "&#255;",
-	      );
-
-my $entities = join('|', keys %entity);
 
 sub encode {
 	my ($self, $text) = @_;
 	return $text unless $self->{'encode_output'};
-	
+
 	my $encoded_text = '';
 	
 	while ( $text =~ s/(.*?)(\<\!\[CDATA\[.*?\]\]\>)//s ) {
-		$encoded_text .= encode_text($1) . $2;
+		$encoded_text .= encode_entities($1) . $2;
 	}
-	$encoded_text .= encode_text($text);
+	$encoded_text .= encode_entities($text);
 
 	return $encoded_text;
 }
 
-sub encode_text {
-	my $text = shift;
-	
-	$text =~ s/&(?!(#[0-9]+|#x[0-9a-fA-F]+|\w+);)/&amp;/g;
-    $text =~ s/&($entities);/$entity{$1}/g;
-    $text =~ s/</&lt;/g;
-
-	return $text;
-}
-
 1;
 __END__
 
@@ -1912,7 +1800,7 @@ XML::RSS - creates and updates RSS files
         # creates a guid field with permaLink=true
         permaLink  => "http://freshmeat.net/news/1999/06/21/930003829.html",
 		# alternately creates a guid field with permaLink=false
-        # guid     => "gtkeyboard-0.85
+        # guid     => "gtkeyboard-0.85"
         enclosure   => { url=>$url, type=>"application/x-bittorrent" },
         description => 'blah blah'
 );
